/***************************************************************************//**
* \file .h
* \version 4.0
*
* \brief
*  This private file provides constants and parameter values for the
*  SCB Component.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_UART_TeraTerm_H)
#define CY_SCB_PVT_UART_TeraTerm_H

#include "UART_TeraTerm.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define UART_TeraTerm_SetI2CExtClkInterruptMode(interruptMask) UART_TeraTerm_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define UART_TeraTerm_ClearI2CExtClkInterruptSource(interruptMask) UART_TeraTerm_CLEAR_INTR_I2C_EC(interruptMask)
#define UART_TeraTerm_GetI2CExtClkInterruptSource()                (UART_TeraTerm_INTR_I2C_EC_REG)
#define UART_TeraTerm_GetI2CExtClkInterruptMode()                  (UART_TeraTerm_INTR_I2C_EC_MASK_REG)
#define UART_TeraTerm_GetI2CExtClkInterruptSourceMasked()          (UART_TeraTerm_INTR_I2C_EC_MASKED_REG)

#if (!UART_TeraTerm_CY_SCBIP_V1)
    /* APIs to service INTR_SPI_EC register */
    #define UART_TeraTerm_SetSpiExtClkInterruptMode(interruptMask) \
                                                                UART_TeraTerm_WRITE_INTR_SPI_EC_MASK(interruptMask)
    #define UART_TeraTerm_ClearSpiExtClkInterruptSource(interruptMask) \
                                                                UART_TeraTerm_CLEAR_INTR_SPI_EC(interruptMask)
    #define UART_TeraTerm_GetExtSpiClkInterruptSource()                 (UART_TeraTerm_INTR_SPI_EC_REG)
    #define UART_TeraTerm_GetExtSpiClkInterruptMode()                   (UART_TeraTerm_INTR_SPI_EC_MASK_REG)
    #define UART_TeraTerm_GetExtSpiClkInterruptSourceMasked()           (UART_TeraTerm_INTR_SPI_EC_MASKED_REG)
#endif /* (!UART_TeraTerm_CY_SCBIP_V1) */

#if(UART_TeraTerm_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void UART_TeraTerm_SetPins(uint32 mode, uint32 subMode, uint32 uartEnableMask);
#endif /* (UART_TeraTerm_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Vars with External Linkage
***************************************/

#if (UART_TeraTerm_SCB_IRQ_INTERNAL)
#if !defined (CY_REMOVE_UART_TeraTerm_CUSTOM_INTR_HANDLER)
    extern cyisraddress UART_TeraTerm_customIntrHandler;
#endif /* !defined (CY_REMOVE_UART_TeraTerm_CUSTOM_INTR_HANDLER) */
#endif /* (UART_TeraTerm_SCB_IRQ_INTERNAL) */

extern UART_TeraTerm_BACKUP_STRUCT UART_TeraTerm_backup;

#if(UART_TeraTerm_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common configuration variables */
    extern uint8 UART_TeraTerm_scbMode;
    extern uint8 UART_TeraTerm_scbEnableWake;
    extern uint8 UART_TeraTerm_scbEnableIntr;

    /* I2C configuration variables */
    extern uint8 UART_TeraTerm_mode;
    extern uint8 UART_TeraTerm_acceptAddr;

    /* SPI/UART configuration variables */
    extern volatile uint8 * UART_TeraTerm_rxBuffer;
    extern uint8   UART_TeraTerm_rxDataBits;
    extern uint32  UART_TeraTerm_rxBufferSize;

    extern volatile uint8 * UART_TeraTerm_txBuffer;
    extern uint8   UART_TeraTerm_txDataBits;
    extern uint32  UART_TeraTerm_txBufferSize;

    /* EZI2C configuration variables */
    extern uint8 UART_TeraTerm_numberOfAddr;
    extern uint8 UART_TeraTerm_subAddrSize;
#endif /* (UART_TeraTerm_SCB_MODE_UNCONFIG_CONST_CFG) */

#if (! (UART_TeraTerm_SCB_MODE_I2C_CONST_CFG || \
        UART_TeraTerm_SCB_MODE_EZI2C_CONST_CFG))
    extern uint16 UART_TeraTerm_IntrTxMask;
#endif /* (! (UART_TeraTerm_SCB_MODE_I2C_CONST_CFG || \
              UART_TeraTerm_SCB_MODE_EZI2C_CONST_CFG)) */


/***************************************
*        Conditional Macro
****************************************/

#if(UART_TeraTerm_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Defines run time operation mode */
    #define UART_TeraTerm_SCB_MODE_I2C_RUNTM_CFG     (UART_TeraTerm_SCB_MODE_I2C      == UART_TeraTerm_scbMode)
    #define UART_TeraTerm_SCB_MODE_SPI_RUNTM_CFG     (UART_TeraTerm_SCB_MODE_SPI      == UART_TeraTerm_scbMode)
    #define UART_TeraTerm_SCB_MODE_UART_RUNTM_CFG    (UART_TeraTerm_SCB_MODE_UART     == UART_TeraTerm_scbMode)
    #define UART_TeraTerm_SCB_MODE_EZI2C_RUNTM_CFG   (UART_TeraTerm_SCB_MODE_EZI2C    == UART_TeraTerm_scbMode)
    #define UART_TeraTerm_SCB_MODE_UNCONFIG_RUNTM_CFG \
                                                        (UART_TeraTerm_SCB_MODE_UNCONFIG == UART_TeraTerm_scbMode)

    /* Defines wakeup enable */
    #define UART_TeraTerm_SCB_WAKE_ENABLE_CHECK       (0u != UART_TeraTerm_scbEnableWake)
#endif /* (UART_TeraTerm_SCB_MODE_UNCONFIG_CONST_CFG) */

/* Defines maximum number of SCB pins */
#if (!UART_TeraTerm_CY_SCBIP_V1)
    #define UART_TeraTerm_SCB_PINS_NUMBER    (7u)
#else
    #define UART_TeraTerm_SCB_PINS_NUMBER    (2u)
#endif /* (!UART_TeraTerm_CY_SCBIP_V1) */

#endif /* (CY_SCB_PVT_UART_TeraTerm_H) */


/* [] END OF FILE */
