/*
  =========================================
  Created by : Dwi Wahyudi
  Email : dwiwahyudi1996@gmail.com
  From : Indonesian
  Reference : Davide Marzorati (https://github.com/dado93)

  copyright Dwi Wahyudi, Cilegon, 2019
  =========================================
*/
#include "project.h"
#include "mpu9250.h"
#include "i2c_mpu9250.h"
#include "stdio.h"

int main(void)
{
    CyGlobalIntEnable; /* Enable global interrupts. */
    
    // Start UART component
    UART_TeraTerm_Start();
    
    UART_TeraTerm_UartPutString("**************\r\n");
    UART_TeraTerm_UartPutString("    MPU9250   \r\n");
    UART_TeraTerm_UartPutString("**************\r\n");
    
    // Start I2C component
    I2C_MPU9250_Start();
    
    CyDelay(1000);
    
    char message[30];       // Message to send over UART
    uint8_t connection = 0; // Variable to store connection status
    
    // Scan I2C bus and find devices
    for (int address = 0; address < 128; address++) {
        if (I2C_MPU9250_I2CMasterSendStart(address, 0, I2C_TimeOut) == I2C_MPU9250_I2C_MSTR_NO_ERROR) {
            sprintf(message, "Found device at: 0x%02x\r\n", address);
            UART_TeraTerm_UartPutString(message);
        }
        I2C_MPU9250_I2CMasterSendStop(I2C_TimeOut);
    }
    
    // Wait until MPU9250 is connected
    do {
        connection = MPU9250_IsConnected();
    } while (connection == 0);
    
    // Show connection status feedback
    //Connection_Led_Write(1);
    
    // Star the MPU9250
    MPU9250_Start();
    MPU9250_SetAccFS(MPU9250_Acc_FS_2g);
    

    // Read WHO AM I register and compare with the expected value
    uint8_t whoami = MPU9250_ReadWhoAmI();
    sprintf(message, "WHO AM I: 0x%02x - Expected: 0x%02x\r\n", whoami, MPU9250_WHO_AM_I);
    UART_TeraTerm_UartPutString(message);
    
    //MPU9250_ISR_StartEx(MPU9250_DR_ISR); //Interupt

    /* Place your initialization/startup code here (e.g. MyInst_Start()) */

    for(;;)
    {
        /* Place your application code here. */
    }
}

CY_ISR(MPU9250_DR_ISR) {
    // prepare packet
    static uint8_t data[14];
    // header
    data[0] = 0xA0;
    // footer
    data[13] = 0xC0;
    // read data
    MPU9250_ReadAccGyroRaw(&data[1]);
    // send packet over uart
    UART_TeraTerm_SpiUartPutArray(data,14);
    MPU9250_ReadInterruptStatus();
}

/* [] END OF FILE */
